# entity_selector_jupyter_widget

A Jupyter Widget library for selecting entities in text

## Installation

To install use pip:
```bash
    $ pip install entity_selector_jupyter_widget
    $ jupyter nbextension enable --py --sys-prefix entity_selector_jupyter_widget
```

For a development installation (requires npm),
```bash
    $ git clone https://gitlab.com/randomunrandom/entity_selector_jupyter_widget.git
    $ cd entity_selector_jupyter_widget
    $ ./dev.sh
    ### if you want to rebuild extension run ./dev again
```

## JupyterLab
Due to major differences between the Jupyter Notebook and JupyterLab, the extensions will not work in JupyterLab.